┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/viewsettingspage.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/viewsettingspage.h')
-rw-r--r--src/viewsettingspage.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/viewsettingspage.h b/src/viewsettingspage.h
index 1b068cd19..012842dc2 100644
--- a/src/viewsettingspage.h
+++ b/src/viewsettingspage.h
@@ -23,6 +23,7 @@
#include <qwidget.h>
#include <settingspagebase.h>
+class ColumnViewSettingsPage;
class DolphinMainWindow;
class GeneralViewSettingsPage;
class IconsViewSettingsPage;
@@ -31,8 +32,8 @@ class DetailsViewSettingsPage;
/**
* @brief Page for the 'View' settings of the Dolphin settings dialog.
*
* The views settings allow to set the properties for the icons mode and
* the details mode.
*/
class ViewSettingsPage : public SettingsPageBase
{
@@ -49,6 +50,7 @@ private:
GeneralViewSettingsPage* m_generalPage;
IconsViewSettingsPage* m_iconsPage;
DetailsViewSettingsPage* m_detailsPage;
+ ColumnViewSettingsPage* m_columnPage;
};
#endif
@@ -31,8 +32,8 @@ class DetailsViewSettingsPage;
* @brief Page for the 'View' settings of the Dolphin settings dialog.
*
- * The views settings allow to set the properties for the icons mode and
- * the details mode.
+ * The views settings allow to set the properties for the icons mode,
+ * the details mode and the column mode.
*/
class ViewSettingsPage : public SettingsPageBase